@@ -18,44 +18,49 @@ import boto3
 import inquirer
 from dateutil.parser import parse
 from dateutil.tz import UTC, tzlocal
+from . import jira_approval
 
 AWS_CONFIG_DIR = f'{Path.home()}/.aws'
 AWS_CONFIG_PATH = f'{Path.home()}/.aws/config'
 AWS_CREDENTIAL_PATH = f'{Path.home()}/.aws/credentials'
 AWS_SSO_CACHE_PATH = f'{Path.home()}/.aws/sso/cache'
-AWS_DEFAULT_REGION = 'us-west-1'
+AWS_DEFAULT_REGION = 'us-west-2'
 CURRENT_REGION = os.getenv('AWS_REGION')
-AWS_OPS1_ACCOUNT = '101790543458'
-AWS_OPS1_REGION = 'us-west-1'
+AWS_OPS2_ACCOUNT = '731045533415'
+AWS_OPS2_REGION = 'us-west-2'
 
 if not CURRENT_REGION:
     current_session = boto3.session.Session()
     CURRENT_REGION = current_session.region_name
 if not CURRENT_REGION:
-    CURRENT_REGION = 'us-west-1'
+    CURRENT_REGION = 'us-west-2'
 
 default_config = {
   'sso_start_url': 'https://hireteammate.awsapps.com/start',
   'sso_region': 'us-west-2',
-  'sso_account_id': '780323805217',
+  'sso_account_id': '731045533415',
   'sso_role_name': 'default',
-  'region': 'us-west-1',
+  'region': 'us-west-2',
   'output': 'json'
 }
 
 account_map = {
-    'HireEz-OPS1': ['ops1', 'us-west-1'],
-    'HireEz-OPS2': ['ops2', 'us-west-2'],
-    'Hiretaul Resold': ['master', 'us-west-2'],
-    'Test': ['test', 'us-west-1'],
-    'Stage': ['stage', 'us-west-1'],
-    'prod': ['prod', 'us-west-1'],
-    'HireEz-TEST1': ['test1', 'us-west-1'],
-    'HireEz-TEST2': ['test2', 'us-west-2'],
-    'HireEz-STAGE1': ['stage1', 'us-west-1'],
-    'HireEz-STAGE2': ['stage2', 'us-west-2'],
-    'HireEz-PROD1': ['prod1', 'us-west-1'],
-    'HireEz-PROD2': ['prod2', 'us-west-2']
+    'HireEz-CORE-OPS1': ['ops1', 'us-east-1'],
+    'HireEz-CORE-OPS2': ['ops2', 'us-west-2'],
+    'HireEz-Legacy': ['prod', 'us-west-1'],
+    'HireEz-CORE-TEST2': ['test2', 'us-west-2'],
+    'HireEz-CORE-STAGE1': ['stage1', 'us-west-1'],
+    'HireEz-CORE-STAGE2': ['stage2', 'us-west-2'],
+    'HireEz-CORE-PROD1': ['prod1', 'us-east-1'],
+    'HireEz-CORE-PROD2': ['prod2', 'us-west-2'],
+    'HireEz-ML-TEST': ['ml-test', 'us-west-2'],
+    'HireEz-ML-STAGE': ['ml-stage', 'us-west-2'],
+    'HireEz-ML-PROD': ['ml-prod', 'us-west-2'],
+    'HireEz-STARTREE-PROD2': ['startree-prod2', 'us-west-2'],
+    'HireEz-STARTREE-TEST2': ['startree-test2', 'us-west-2'],
+    'HireEz-STARTREE-STAGE2': ['startree-stage2', 'us-west-2'],
+    'Hiretaul Resold': ['hiretual-', 'us-west-2'],
+    'HireEz-Marketplace': ['marketplace', 'us-west-2']
 }
 
 if not os.path.exists(AWS_CONFIG_DIR):
@@ -82,23 +87,15 @@ def main():
     parser.add_argument('-i',
         action='store_true',
         help='check aws session.')
-#    parser_sso = subparsers.add_parser('sso')
-#    parser_sso_sub = parser_sso.add_subparsers()
-#    parser_sso_config = parser_sso_sub.add_parser('config',
-#                        help='config aws sso.')
-#    parser_sso_config.set_defaults(func=_sso_config)
-#
-#    parser_sso_login = parser_sso_sub.add_parser('login',
-#                        help='ssm login into sso.')
-#    parser_sso_login.set_defaults(func=_sso_login)
-#
-#    parser_sso_switch = parser_sso_sub.add_parser('switch',
-#                        help='switch to another config.')
-#    parser_sso_switch.set_defaults(func=_sso_switch)
-#
-#    parser_sso_logout = parser_sso_sub.add_parser('logout',
-#                        help='logout aws sso.')
-#    parser_sso_logout.set_defaults(func=_sso_logout)
+
+    parser_jira = subparsers.add_parser('jira')
+    parser_jira_sub = parser_jira.add_subparsers()
+    parser_jira_login = parser_jira_sub.add_parser('login',
+                        help='login jira with your token.')
+    parser_jira_login.set_defaults(func=_jira_login)
+    parser_jira_get = parser_jira_sub.add_parser('get',
+                        help='list all your Jira(CMR) open tickets.')
+    parser_jira_get.set_defaults(func=_jira_get)
 
     parser_env = subparsers.add_parser('env')
     parser_env_sub = parser_env.add_subparsers()
@@ -158,6 +155,23 @@ def main():
     parser_sm_delete.add_argument('secret')
     parser_sm_delete.set_defaults(func=_sm_delete)
 
+    parser_ssm = subparsers.add_parser('ssm')
+    parser_ssm_sub = parser_ssm.add_subparsers()
+    parser_ssm_search = parser_ssm_sub.add_parser('search',
+                        help='search parameters')
+    parser_ssm_search.add_argument('parameter')
+    parser_ssm_search.set_defaults(func=_ssm_search)
+
+    parser_ssm_get = parser_ssm_sub.add_parser('get',
+                        help='get parameter value')
+    parser_ssm_get.add_argument('parameter')
+    parser_ssm_get.set_defaults(func=_ssm_get)
+
+    parser_ssm_delete = parser_ssm_sub.add_parser('delete',
+                        help='delete parameter value')
+    parser_ssm_delete.add_argument('parameter')
+    parser_ssm_delete.set_defaults(func=_ssm_delete)
+
     parser_image = subparsers.add_parser('image')
     parser_image_sub = parser_image.add_subparsers()
     parser_image_list = parser_image_sub.add_parser('list',
@@ -171,6 +185,14 @@ def main():
                         help='image full name.')
     parser_image_pull.set_defaults(func=_image_pull)
 
+    parser_image_cve = parser_image_sub.add_parser('cve',
+                        help='get image cve report.')
+    parser_image_cve.add_argument('service',
+                        help='service name.')
+    parser_image_cve.add_argument('tag',
+                        help='service image tag')
+    parser_image_cve.set_defaults(func=_image_cve)
+
     parser_image_run = parser_image_sub.add_parser('run',
                         help='run service image with envs injected. eg: awsso image run emailserver ac702bf [5051]')
     parser_image_run.add_argument('service',
@@ -209,6 +231,10 @@ def main():
 #            _sso_switch()
 #        if args.func == _sso_logout:
 #            _sso_logout()
+        if args.func == _jira_login:
+            _jira_login()
+        if args.func == _jira_get:
+            _jira_get()
         if args.func == _env_get:
             _env_get(args.service)
         if args.func == _env_load:
@@ -229,10 +255,18 @@ def main():
             _sm_update(args.secret)
         if args.func == _sm_delete:
             _sm_delete(args.secret)
+        if args.func == _ssm_search:
+            _ssm_search(args.parameter)
+        if args.func == _ssm_get:
+            _ssm_get(args.parameter)
+        if args.func == _ssm_delete:
+            _ssm_delete(args.parameter)
         if args.func == _image_list:
             _image_list(args.service)
         if args.func == _image_pull:
             _image_pull(args.image)
+        if args.func == _image_cve:
+            _image_cve(args.service, args.tag)
         if args.func == _image_run:
             _image_run(args.service, args.tag)
 
@@ -468,7 +502,8 @@ def _gen_config_file():
             if r1.get('ResponseMetadata').get('HTTPStatusCode') == 200:
                 for role in r1.get('roleList'):
                     role = role.get('roleName')
-                    p_name = 'profile {}{}'.format(profile_name, role)
+                    _pname = re.sub(r'\d', '', profile_name)
+                    p_name = 'profile {}{}'.format(profile_name, role.replace(_pname.upper(), '', 1))
                     if config.has_section(p_name):
                         config.remove_section(p_name)
                     #if not re.match('^[A-Z].*', role):
@@ -689,6 +724,85 @@ def _sm_delete(keyword):
         print('The sm: {} will not be deleted'.format(keyword))
         sys.exit()
 
+def ssm_search(keyword, option='Contains'):
+    client = boto3.client('ssm', region_name=CURRENT_REGION)
+    _filter = [
+        {
+            'Key': 'Name',
+            'Option': option,
+            'Values': [ keyword ]
+        }
+    ]
+    ret = client.describe_parameters(ParameterFilters=_filter, MaxResults=50)
+    _ret_list = ret['Parameters']
+    _next = ret.get('NextToken')
+    while _next:
+        ret_tmp = client.describe_parameters(ParameterFilters=_filter, MaxResults=50, NextToken=_next)
+        _ret_list.extend(ret_tmp['Parameters'])
+        _next = ret_tmp.get('NextToken')
+
+    ret_list = [ i['Name'] for i in _ret_list ]
+    return ret_list
+
+def _ssm_search(keyword):
+    ret_list = ssm_search(keyword)
+    if len(ret_list) == 0:
+        print('Did not find any parameters.')
+        sys.exit()
+    questions = [
+        inquirer.List(
+            'name',
+            message='Please select parameter',
+            choices=ret_list
+        ),
+    ]
+    answer = inquirer.prompt(questions)
+    client = boto3.client('ssm', region_name=CURRENT_REGION)
+    ret = client.get_parameter(Name=answer['name'], WithDecryption=True)
+    print(ret['Parameter']['Value'])
+
+def _ssm_get(keyword):
+    client = boto3.client('ssm', region_name=CURRENT_REGION)
+    try:
+        ret = client.get_parameter(Name=keyword, WithDecryption=True)
+        print(ret['Parameter']['Value'])
+    except:
+        print('Get parameter error.')
+        sys.exit(1)
+
+def _ssm_delete(keyword):
+    client = boto3.client('ssm', region_name=CURRENT_REGION)
+    data = input('Please confirm this deletion[y/n]: ')
+    if data.strip().lower() == 'y':
+        if not keyword.endswith('/'):
+            print('The ssm: {} will be deleted'.format(keyword))
+            try:
+                ret = client.delete_parameter(Name=keyword)
+                print(ret)
+            except client.exceptions.ParameterNotFound:
+                print('Pamameter not found.')
+        else:
+            print('The ssm startswith {} will be deleted'.format(keyword))
+            ret_list = ssm_search(keyword, 'BeginsWith')
+            for r in ret_list:
+                print(r)
+                try:
+                    ret = client.delete_parameter(Name=r)
+                    print(ret)
+                except client.exceptions.ParameterNotFound:
+                    print('Pamameter not found.')
+    else:
+        print('Cancelled.')
+        sys.exit()
+
+def _jira_login():
+    jira_approval.save_config()
+    jira_config = jira_approval.load_config()
+    jira_approval.validate_config(jira_config)
+
+def _jira_get():
+    jira_approval.jira_ticket_transaction()
+
 def _env_get(service):
 
     def GetPathToken(path, Token):
@@ -796,7 +910,8 @@ def _env_load(service):
     print("")
     for item in info:
         value=item['Value']
-        tier = "Advanced" if len(value) > 4096 else "Standard"
+        #tier = "Advanced" if len(value) > 4096 else "Standard"
+        tier = "Intelligent-Tiering"
         print(item['Param'], "=", value)
 
         try:
@@ -817,10 +932,10 @@ def _env_load(service):
     print("")
 
 def _image_list(service):
-    client = boto3.client('ecr')
+    client = boto3.client('ecr', region_name=AWS_OPS2_REGION)
     try:
         ret = client.list_images(
-            registryId=AWS_OPS1_ACCOUNT,
+            registryId=AWS_OPS2_ACCOUNT,
             repositoryName=service,
             filter={
                 'tagStatus': 'TAGGED'
@@ -840,11 +955,11 @@ def _image_list(service):
     for i in _ret_list:
         ret_list.append(i['imageTag'])
     for j in ret_list:
-        print('{}.dkr.ecr.{}.amazonaws.com/{}:{}'.format(AWS_OPS1_ACCOUNT, AWS_OPS1_REGION, service, j))
+        print('{}.dkr.ecr.{}.amazonaws.com/{}:{}'.format(AWS_OPS2_ACCOUNT, AWS_OPS2_REGION, service, j))
 
 def _image_pull(image):
     subprocess.run('aws ecr get-login-password --region {1} | docker login --username AWS \
-        --password-stdin {0}.dkr.ecr.{1}.amazonaws.com'.format(AWS_OPS1_ACCOUNT, AWS_OPS1_REGION),
+        --password-stdin {0}.dkr.ecr.{1}.amazonaws.com'.format(AWS_OPS2_ACCOUNT, AWS_OPS2_REGION),
         shell=True,
         stderr=sys.stderr,
         stdout=sys.stdout,
@@ -854,6 +969,14 @@ def _image_pull(image):
         stdout=sys.stdout,
         check=True)
 
+def _image_cve(service, tag):
+    subprocess.run('aws ecr describe-image-scan-findings --region {1} --registry-id {0} --repository-name {2} \
+        --image-id imageTag={3} | jq ".imageScanFindings.findings[] | \\"\(.severity) \(.name) \(.description)\\""'.format(AWS_OPS2_ACCOUNT, AWS_OPS2_REGION, service, tag),
+        shell=True,
+        stderr=sys.stderr,
+        stdout=sys.stdout,
+        check=True)
+
 def _image_run(service, tag):
     port_cmd = ''
     if len(tag) == 2:
@@ -865,7 +988,7 @@ def _image_run(service, tag):
             sys.exit(1)
         
     run_cmd = 'docker run --rm -d {4} -v ~/.aws:/root/.aws --env-file ~/.{0}_env \
-{1}.dkr.ecr.{2}.amazonaws.com/{0}:{3}'.format(service, AWS_OPS1_ACCOUNT, AWS_OPS1_REGION, tag[0], port_cmd)
+{1}.dkr.ecr.{2}.amazonaws.com/{0}:{3}'.format(service, AWS_OPS2_ACCOUNT, AWS_OPS2_REGION, tag[0], port_cmd)
     try:
         subprocess.run(run_cmd,
             shell=True,
